Structs
- Error when parsing trfr text.
- The record fields in a
trftable - An owned iterator over the records of a refer file.
- A borrowed iterator over the records of a refer file.
Enums
- Specific errors that can happen.
Type Aliases
- A type alias for
Result<T, trfr::Error>.